@@ -23,19 +23,31 @@ class fatFuckSQL:
     
     async def fetch(self, query: str, *args):
         async with self._pool.acquire() as con:
-            return await con.fetch(query, args)
+            if args: # stupid asyncpg
+                return await con.fetch(query, args)
+            else:
+                return await con.fetch(query)
 
     async def fetchval(self, query: str, *args):
         async with self._pool.acquire() as con:
-            return await con.fetchval(query, args)
+            if args: # stupid asyncpg
+                return await con.fetchval(query, args)
+            else:
+                return await con.fetchval(query)
 
     async def fetchrow(self, query: str, *args):
         async with self._pool.acquire() as con:
-            return await con.fetch(query, args)
+            if args: # stupid asyncpg
+                return await con.fetchrow(query, args)
+            else:
+                return await con.fetchrow(query)
 
     async def execute(self, query: str, *args):
         async with self._pool.acquire() as con:
-            return await con.execute(query, args)
-        
+            if args: # stupid asyncpg
+                return await con.execute(query, args)
+            else:
+                return await con.execute(query)
+
     async def close(self):
         await self._pool.close()
\ No newline at end of file
